@@ -321,7 +321,7 @@ build_font_name (const char *style_name,
                  int weight,
                  gboolean short_form)
 {
-    const char *style_name_x = style_name;
+    g_autofree char *style_name_x = g_strdup (style_name);
     const gchar *slant_name = slant_to_name (slant);
     const gchar *weight_name = weight_to_name (weight);
 
@@ -401,7 +401,7 @@ load_font_infos (GTask *task,
             continue;
 
         // TODO: Support scripts which don't contain "Aa"
-        const char *font_preview_text = g_strdup ("Aa");
+        const char *font_preview_text = "Aa";
 
         PangoFontDescription *font_description = pango_font_description_new ();
 
