@@ -94,7 +94,7 @@ font_attribute_closure (gpointer obj,
     pango_attr_list_insert (list, attr);
   }
 
-  return pango_attr_list_copy (list);
+  return list;
 }
 
 static char *
@@ -350,6 +350,8 @@ get_features (FT_Face face)
                 }
             }
         }
+
+        hb_font_destroy (hb_font);
     }
 
     if (s->len > 0)
@@ -716,6 +718,7 @@ font_widget_loaded_cb (FontViewWindow  *self,
     return;
 
   uri = sushi_font_widget_get_uri (font_widget);
+  g_clear_object (&self->font_file);
   self->font_file = g_file_new_for_uri (uri);
 
   if (face->family_name) {
