@@ -659,9 +659,8 @@ sushi_font_widget_snapshot (GtkWidget *drawing_area,
   allocated_width = gtk_widget_get_allocated_width (drawing_area);
   allocated_height = gtk_widget_get_allocated_height (drawing_area);
 
-  graphene_rect_t* rect = graphene_rect_alloc();
-  graphene_rect_init(rect, 0, 0, allocated_width, allocated_height);
-  cairo_t* cr = gtk_snapshot_append_cairo (snapshot, rect);
+  graphene_rect_t rect = GRAPHENE_RECT_INIT (0, 0, allocated_width, allocated_height);
+  cairo_t* cr = gtk_snapshot_append_cairo (snapshot, &rect);
   gtk_render_background (context, cr,
                          0, 0, allocated_width, allocated_height);
 
@@ -727,6 +726,7 @@ font_face_async_ready_cb (GObject *object,
   SushiFontWidget *self = user_data;
   g_autoptr(GError) error = NULL;
 
+  g_clear_pointer (&self->face_contents, g_free);
   self->face =
     sushi_new_ft_face_from_uri_finish (result,
                                        &self->face_contents,
@@ -795,6 +795,7 @@ sushi_font_widget_set_property (GObject *object,
 
   switch (prop_id) {
   case PROP_URI:
+    g_clear_pointer (&self->uri, g_free);
     self->uri = g_value_dup_string (value);
     break;
   case PROP_FACE_INDEX:
